# write
consultation_har_ingest2_write <- function(json.dir, json.file){
  
  # Packages
  require(dplyr)
  require(jsonlite)
  require(data.table)
  
  # Load JSON file
  df <- fromJSON(txt = paste0(json.dir,json.file))$data
  
  # Convert df to data.table format
  df <- data.table::as.data.table(df)
  
  # id_center
  df$id_center[ df$id_center == ""] <- NA
  
  # residence_place
  df$residence_place[ df$residence_place == ""] <- NA
  
  # infection_place
  df$infection_place[ df$infection_place == ""] <- NA
  
  # id_consultation
  df$id_consultation[ df$id_consultation == ""] <- NA
  
  # consultation_date
  df$consultation_date <- as.Date(df$consultation_date, format = "%d/%m/%Y")
  
  # diagnosis_result
  df$diagnosis_result <- as.factor(df$diagnosis_result) %>%
    dplyr::recode(., "1" = "Negative", "2" = "Falciparum", "3" = "F + FG", "4" = "Vivax", "5" = "F + V",
                  "6" = "V + FG", "7" = "FG", "8" = "Malariae", "9" = "F + M", "10" = "Ovale", "11" = "Non Falciparum")
  
  # patient_age
  df$patient_age <- as.numeric(df$patient_age)
  df$patient_age[ df$patient_age > 100] <- NA
  
  # patient_sex
  df$patient_sex <- as.factor(df$patient_sex) %>%
    dplyr::recode(., "0" =  "Desconhecido", "1" = "Male", "2" = "Female", "9" = "Desconhecido")
  
  # active_diagnosis
  df$active_diagnosis <- as.logical(df$active_diagnosis)
  
  # new_attack
  df$new_attack <- as.logical(df$new_attack)
  
  tbl <- as_tibble(df)
  readr::write_csv(tbl, "data/JSON_consultation_har.csv")
  # Return pre-processed data
  return(tbl)
}

consultation_har_ingest2_load <- function(csv_file) {
  df <- readr::read_csv(csv_file)
  return(df)
}