### Ranking tab

##################
### Data objects
##################


DOWN_residencial_area_fg <- JSON_area_har %>%
  filter(source == "FR-GF") %>%
  select(id, name) %>%
  arrange(name)
DOWN_residencial_area_list_fg <- as.list(DOWN_residencial_area_fg$id)
names(DOWN_residencial_area_list_fg) <- DOWN_residencial_area_fg$name

DOWN_residencial_area_br <- JSON_area_har %>%
  filter(source == "BR") %>%
  select(id, name) %>%
  arrange(name)
DOWN_residencial_area_list_br <- as.list(DOWN_residencial_area_br$id)
names(DOWN_residencial_area_list_br) <- DOWN_residencial_area_br$name

DOWN_health_center_fg <- JSON_healthcenter_har %>%
  filter(source == "FR-GF") %>%
  select(id_center, name) %>%
  arrange(name)
DOWN_health_center_list_fg <- as.list(DOWN_health_center_fg$id_center)
names(DOWN_health_center_list_fg) <- DOWN_health_center_fg$name

DOWN_health_center_br <- JSON_healthcenter_har %>%
  filter(source == "BR") %>%
  select(id_center, name) %>%
  arrange(name)
DOWN_health_center_list_br <- as.list(DOWN_health_center_br$id_center)
names(DOWN_health_center_list_br) <- DOWN_health_center_br$name


output$DOWNlocation_fg <- renderUI({
  switch(input$DOWNtype,
         "residence_area" = selectInput("DOWNselection_fg", tr("FG"), DOWN_residencial_area_list_fg, multiple = TRUE),
         "center" = selectInput("DOWNselection_fg", tr("FG"), DOWN_health_center_list_fg, multiple = TRUE),
         "infection_place" = selectInput("DOWNselection_fg", tr("FG"), DOWN_residencial_area_list_fg, multiple = TRUE)
  )
})

output$DOWNlocation_br <- renderUI({
  switch(input$DOWNtype,
         "residence_area" = selectInput("DOWNselection_br", tr("BR"), DOWN_residencial_area_list_br, multiple = TRUE),
         "center" = selectInput("DOWNselection_br", tr("BR"), DOWN_health_center_list_br, multiple = TRUE),
         "infection_place" = selectInput("DOWNselection_br", tr("BR"), DOWN_residencial_area_list_br, multiple = TRUE)
  )
})





DOWN_tab <- reactive({
  
  date1 <- as.Date(paste0(input$DOWNdates[1],"-01-01"))
  date2 <- as.Date(paste0(input$DOWNdates[2],"-12-31"))
  
  df <- consultation_har_filter(JSON_cons_har,
                          new_attack = input$DOWNnew_attack,
                          diagn = input$DOWNdiagn,
                          sex = input$DOWNsex,
                          minAge = input$DOWNage[1], maxAge = input$DOWNage[2]
  ) %>%
    filter(consultation_date >= date1 & consultation_date <= date2)
  
  if(input$DOWNtype == "center"){
    df <- df %>% filter(id_center %in% c(input$DOWNselection_fg, input$DOWNselection_br))
  } else if(input$DOWNtype == "residence_area"){
    df <- df %>% filter(residence_place %in% c(input$DOWNselection_fg, input$DOWNselection_br))
  } else if(input$DOWNtype == "infection_place"){
    df <- df %>% filter(infection_place %in% c(input$DOWNselection_fg, input$DOWNselection_br))
  }
  
  df <- df %>% select(
    source,
    id_center,
    residence_place,
    infection_place,
    consultation_date,
    patient_sex,
    patient_age,
    new_attack,
    diagnosis_result
  )
  
  return(df)
  
})

##################
### Table
##################

output$DOWN_table <- renderDataTable(
    DOWN_tab(),
    server = FALSE,
    rownames= FALSE, 
    extensions = 'Buttons', 
    options = list(
      dom = 'Bfrtip',
      buttons = c('copy', 'csv', 'excel', 'pdf', 'print')
    )
)