### Harmonized tab

date1 <- reactive({
  as.Date(paste0(input$dates[1],"-01-01"))
})

date2 <- reactive({
  date2 <- as.Date(paste0(input$dates[2],"-12-31"))
})

# Filter
HAR_sub <- reactive({
  
  date1 <- as.Date(paste0(input$dates[1],"-01-01"))
  date2 <- as.Date(paste0(input$dates[2],"-12-31"))
  
  consultation_har_filter(JSON_cons_har,
                          new_attack = input$new_attack,
                          diagn = input$diagn,
                          sex = input$sex,
                          minAge = input$age[1], maxAge = input$age[2]
  ) %>%
    filter(consultation_date >= date1 & consultation_date <= date2)
  
})


# Split by country
HAR_br <- reactive({
  HAR_sub() %>% filter(source == "BR")
})
HAR_fg <- reactive({
  HAR_sub() %>% filter(source == "FR-GF")
})

# Tabulate by date of notification
HAR_br_tab <- reactive({
  agg <- as.numeric(input$agg)
  date1 <- as.Date(paste0(input$dates[1],"-01-01"))
  date2 <- as.Date(paste0(input$dates[2],"-12-31"))
  
  if(agg == 1){
    HAR_br() %>% group_by(dates = floor_date(consultation_date, "day")) %>%
      summarize(counts=n()) %>%
      complete(dates = seq.Date(date1, date2, by = "day"), fill = list(counts = 0))
  } else if(agg == 6){
    as.data.frame(incidence(HAR_br()$consultation_date, interval = 7, iso_week = TRUE)) %>%
      select(dates, counts)
  } else if(agg == 30){
    HAR_br() %>% group_by(dates = floor_date(consultation_date, "month")) %>%
      summarize(counts=n()) %>%
      complete(dates = seq.Date(date1, date2, by = "month"), fill = list(counts = 0))
  } else if(agg == 90){
    HAR_br() %>% group_by(dates = floor_date(consultation_date, "quarter")) %>%
      summarize(counts=n()) %>%
      complete(dates = seq.Date(date1, date2, by = "quarter"), fill = list(counts = 0))
  } else if(agg == 366){
    HAR_br() %>% group_by(dates = floor_date(consultation_date, "year")) %>%
      summarize(counts=n()) %>%
      complete(dates = seq.Date(date1, date2, by = "year"), fill = list(counts = 0))
  }
})

HAR_fg_tab <- reactive({
  agg <- as.numeric(input$agg)
  date1 <- as.Date(paste0(input$dates[1],"-01-01"))
  date2 <- as.Date(paste0(input$dates[2],"-12-31"))
  
  if(agg == 1){
    HAR_fg() %>% group_by(dates = floor_date(consultation_date, "day")) %>%
      summarize(counts=n()) %>%
      complete(dates = seq.Date(date1, date2, by = "day"), fill = list(counts = 0))
  } else if(agg == 6){
    as.data.frame(incidence(HAR_fg()$consultation_date, interval = 7, iso_week = TRUE)) %>%
      select(dates, counts)
  } else if(agg == 30){
    HAR_fg() %>% group_by(dates = floor_date(consultation_date, "month")) %>%
      summarize(counts=n()) %>%
      complete(dates = seq.Date(date1, date2, by = "month"), fill = list(counts = 0))
  } else if(agg == 90){
    HAR_fg() %>% group_by(dates = floor_date(consultation_date, "quarter")) %>%
      summarize(counts=n()) %>%
      complete(dates = seq.Date(date1, date2, by = "quarter"), fill = list(counts = NA))
  } else if(agg == 366){
    HAR_fg() %>% group_by(dates = floor_date(consultation_date, "year")) %>%
      summarize(counts=n()) %>%
      complete(dates = seq.Date(date1, date2, by = "year"), fill = list(counts = 0))
  }
})



##################
### Plots and counts
##################

# Count FG
output$HAR_count_fg <- renderValueBox({
  valueBox(
    paste(nrow(HAR_fg()), tr("cases2")), tr("FG"), color = "purple"
  )
})

# Count BR
output$HAR_count_br <- renderValueBox({
  valueBox(
    paste(nrow(HAR_br()), tr("cases2")), tr("BR"), color = "purple"
  )
})

# Plot incidence
output$HAR_plot_incidence <- renderPlotly({
  plot_ly() %>%
    add_trace(data = HAR_br_tab(), x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', 
              name = paste0(tr("BR"), ", ", tr("date_of_retrieval"), " SIVEP-Malária: ", text_recup_donnees_BR)) %>%
    add_trace(data = HAR_fg_tab(), x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', 
              name = paste0(tr("FG"), ", ", tr("date_of_retrieval"), " CHC/CDPS : ", text_recup_donnees_GF)) %>%
    layout(xaxis = list(title = tr("date")), yaxis = list(title = tr("cases"))) %>%
    layout(legend = list(x = 0, y = 1.2))
    # layout(annotations = list(
    #   align="left", bgcolor="gray85", font=list(color="limegreen"),
    #   x=0.5, y=0.7, xref="paper", yref="paper", xanchor = 'left', showarrow=F, 
    #   text=text_recup_donnees))
})

# Plot age
output$HAR_plot_age <- renderPlotly({
  
  HAR_br <- HAR_br() %>% mutate(patient_age = round(patient_age, 0))
  HAR_fg <- HAR_fg() %>% mutate(patient_age = round(patient_age, 0))
  
  plot_ly() %>%
    add_trace(data = HAR_br, x = ~patient_age, type = "histogram", name = tr("BR")) %>%
    add_trace(data = HAR_fg, x = ~patient_age, type = "histogram", name = tr("FG")) %>%
    layout(xaxis = list(title = tr("age"), domain = c(0,100)), yaxis = list(title = tr("cases"))) %>%
    layout(legend = list(x = 0.8, y = 0.9))
})

# Plot sex
output$HAR_plot_sex <- renderPlotly({
  # Country list
  HAR_loc <- c("FG","BR")
  
  # Subset cases with specific sex definition (Brazilian data have some unknown codes)
  HAR_br_sex_sub <- subset(HAR_br(), patient_sex == "Male" | patient_sex == "Female")
  HAR_fg_sex_sub <- subset(HAR_fg(), patient_sex == "Male" | patient_sex == "Female")
  
  # Proportion tables
  HAR_br_sex_tab <- prop.table(table(HAR_br_sex_sub$patient_sex))*100
  HAR_fg_sex_tab <- prop.table(table(HAR_fg_sex_sub$patient_sex))*100
  HAR_male <- c(HAR_fg_sex_tab["Male"],HAR_br_sex_tab["Male"])
  HAR_female <- c(HAR_fg_sex_tab["Female"],HAR_br_sex_tab["Female"])
  HAR_data <- data.frame(HAR_loc, HAR_male, HAR_female)
  
  # Plot
  plot_ly(HAR_data, x = ~HAR_loc, y = ~HAR_male, type = "bar", name = tr("male")) %>%
    add_trace(y = ~HAR_female, name = tr("female")) %>%
    layout(xaxis = list(title = ""), yaxis = list(title = tr("percentage")), barmode = 'stack')
})

# Plot plasmodium
output$HAR_plot_plasm <- renderPlotly({
  # Country list
  HAR_loc <- c("FG","BR")
  
  HAR_br_any <- nrow(consultation_har_filter(HAR_br(), diagn = "Any", new_attack = input$new_attack))
  HAR_fg_any <- nrow(consultation_har_filter(HAR_fg(), diagn = "Any", new_attack = input$new_attack))
  
  HAR_br_falci <- nrow(consultation_har_filter(HAR_br(), diagn = "falciparum", new_attack = input$new_attack))/HAR_br_any*100
  HAR_br_mixed <- nrow(consultation_har_filter(HAR_br(), diagn = "mixed infection with P. falciparum", new_attack = input$new_attack))/HAR_br_any*100
  HAR_br_other <- nrow(consultation_har_filter(HAR_br(), diagn = "non-falciparum", new_attack = input$new_attack))/HAR_br_any*100
  HAR_br_unspe <- nrow(consultation_har_filter(HAR_br(), diagn = "unspecified", new_attack = input$new_attack))/HAR_br_any*100
  HAR_fg_falci <- nrow(consultation_har_filter(HAR_fg(), diagn = "falciparum", new_attack = input$new_attack))/HAR_fg_any*100
  HAR_fg_mixed <- nrow(consultation_har_filter(HAR_fg(), diagn = "mixed infection with P. falciparum", new_attack = input$new_attack))/HAR_fg_any*100
  HAR_fg_other <- nrow(consultation_har_filter(HAR_fg(), diagn = "non-falciparum", new_attack = input$new_attack))/HAR_fg_any*100
  HAR_fg_unspe <- nrow(consultation_har_filter(HAR_fg(), diagn = "unspecified", new_attack = input$new_attack))/HAR_fg_any*100
   
  # Proportion tables
  HAR_falci <- c(HAR_fg_falci, HAR_br_falci)
  HAR_mixed <- c(HAR_fg_mixed, HAR_br_mixed)
  HAR_other <- c(HAR_fg_other, HAR_br_other)
  HAR_unspe <- c(HAR_fg_unspe, HAR_br_unspe)
  HAR_data <- data.frame(HAR_loc, HAR_falci, HAR_other)
  
  # Plot
  plot_ly(HAR_data, x = ~HAR_loc, y = ~HAR_falci, type = "bar", name = "Falci assoc") %>%
    add_trace(y = ~HAR_mixed, name = "Mixed") %>%
    add_trace(y = ~HAR_other, name = "Non falci") %>%
    add_trace(y = ~HAR_unspe, name = "Unspecified") %>%
    layout(xaxis = list(title = ""), yaxis = list(title = tr("percentage")), barmode = 'stack')
  
})
