### Harmonized tab

##################
### Data objects
##################

date1 <- reactive({
  as.Date(paste0(input$HARLOCdates[1],"-01-01"))
})

date2 <- reactive({
  as.Date(paste0(input$HARLOCdates[2],"-12-31"))
})

HARLOC_residencial_area_fg <- JSON_area_har %>%
  filter(source == "FR-GF") %>%
  select(id, name) %>%
  arrange(name)
#HARLOC_residencial_area_list_fg <- HARLOC_residencial_area_fg
HARLOC_residencial_area_list_fg <- with(HARLOC_residencial_area_fg, split(id, name))

HARLOC_residencial_area_br <- JSON_area_har %>%
  filter(source == "BR") %>%
  select(id, name) %>%
  arrange(name)
#HARLOC_residencial_area_list_br <- HARLOC_residencial_area_br
HARLOC_residencial_area_list_br <- with(HARLOC_residencial_area_br, split(id, name))

# HARLOC_health_center_fg <- JSON_healthcenter_har %>%
#   filter(source == "FR-GF") %>%
#   select(id_center, name) %>%
#   arrange(name)
# HARLOC_health_center_list_fg <- as.list(HARLOC_health_center_fg$id_center)
# names(HARLOC_health_center_list_fg) <- HARLOC_health_center_fg$name

HARLOC_health_center_fg <- JSON_healthcenter_har %>%
  filter(source == "FR-GF") %>%
  select(id_center, name) %>%
  arrange(name)
#HARLOC_health_center_list_fg <- HARLOC_health_center_fg
HARLOC_health_center_list_fg <- with(HARLOC_health_center_fg, split(id_center, name))

HARLOC_health_center_br <- JSON_healthcenter_har %>%
  filter(source == "BR") %>%
  select(id_center, name) %>%
  arrange(name)
#HARLOC_health_center_list_br <- HARLOC_health_center_br
HARLOC_health_center_list_br <- with(HARLOC_health_center_br, split(id_center, name))



output$HARLOClocation_fg <- renderUI({
  switch(input$HARLOCtype,
    "residence_area" = selectInput("HARLOCselection_fg", tr("FG"), HARLOC_residencial_area_list_fg, multiple = TRUE, selected = c("ESGOS_CENT")),
    "center" = selectInput("HARLOCselection_fg", tr("FG"), HARLOC_health_center_list_fg, multiple = TRUE, selected = c("CAM","STG")),
    "infection_place" = selectInput("HARLOCselection_fg", tr("FG"), HARLOC_residencial_area_list_fg, multiple = TRUE, selected = c("ESGOS_CENT"))
  )
})

output$HARLOClocation_br <- renderUI({
  switch(input$HARLOCtype,
    "residence_area" = selectInput("HARLOCselection_br", tr("BR"), HARLOC_residencial_area_list_br, multiple = TRUE, selected = c("126")),
    "center" = selectInput("HARLOCselection_br", tr("BR"), HARLOC_health_center_list_br, multiple = TRUE, selected = c("16/160050")),
    "infection_place" = selectInput("HARLOCselection_br", tr("BR"), HARLOC_residencial_area_list_br, multiple = TRUE, selected = c("126"))
  )
})


# Filter
HARLOC_sub_fg <- reactive({

  df <- consultation_har_filter(JSON_cons_har,
                          source = "FG",
                          new_attack = input$HARLOCnew_attack,
                          diagn = input$HARLOCdiagn,
                          sex = input$HARLOCsex,
                          minAge = input$HARLOCage[1], maxAge = input$HARLOCage[2]
  ) %>%
    filter(consultation_date >= date1() & consultation_date <= date2()) 
  

  
  if(input$HARLOCtype == "center"){
    df <- df %>% filter(id_center %in% input$HARLOCselection_fg)
  } else if(input$HARLOCtype == "residence_area"){
    df <- df %>% filter(residence_place %in% input$HARLOCselection_fg)
  } else if(input$HARLOCtype == "infection_place"){
    df <- df %>% filter(infection_place %in% input$HARLOCselection_fg)
  }
  
  return(df)
    
})

HARLOC_sub_br <- reactive({
  
  df <- consultation_har_filter(JSON_cons_har,
                          source = "BR",
                          new_attack = input$HARLOCnew_attack,
                          diagn = input$HARLOCdiagn,
                          sex = input$HARLOCsex,
                          minAge = input$HARLOCage[1], maxAge = input$HARLOCage[2]
  ) %>%
    filter(consultation_date >= date1() & consultation_date <= date2())
    
  if(input$HARLOCtype == "center"){
    df <- df %>% filter(id_center %in% input$HARLOCselection_br)
  } else if(input$HARLOCtype == "residence_area"){
    df <- df %>% filter(residence_place %in% input$HARLOCselection_br)
  } else if(input$HARLOCtype == "infection_place"){
    df <- df %>% filter(infection_place %in% input$HARLOCselection_br)
  }
  
  return(df)

})

# Filter (info quality)
HARLOC_sub_infqual_fg <- reactive({
  
  df <- consultation_har_filter(JSON_cons_har,
                                source = "FG",
                                new_attack = input$HARLOCnew_attack,
                                diagn = input$HARLOCdiagn,
                                sex = input$HARLOCsex,
                                minAge = input$HARLOCage[1], maxAge = input$HARLOCage[2]
  ) %>%
    filter(consultation_date >= date1() & consultation_date <= date2()) %>%
    is.na() %>%
    colMeans() * 100
  
  df <- replace(df, is.nan(df), 100)
  
  return(df)
})

HARLOC_sub_infqual_br <- reactive({
  
  df <- consultation_har_filter(JSON_cons_har,
                                source = "BR",
                                new_attack = input$HARLOCnew_attack,
                                diagn = input$HARLOCdiagn,
                                sex = input$HARLOCsex,
                                minAge = input$HARLOCage[1], maxAge = input$HARLOCage[2]
  ) %>%
    filter(consultation_date >= date1() & consultation_date <= date2()) %>%
    is.na() %>%
    colMeans() * 100
  
  df <- replace(df, is.nan(df), 100)

  return(df)
})


# Tabulate by date (day of the week)
HARLOC_fg_tab_day_week <- reactive({
  if(nrow(HARLOC_sub_fg()) > 0){
    as.data.frame(incidence(HARLOC_sub_fg()$consultation_date, interval = 1))
  }
})
HARLOC_br_tab_day_week <- reactive({
  if(nrow(HARLOC_sub_br()) > 0){
    as.data.frame(incidence(HARLOC_sub_br()$consultation_date, interval = 1))
  }
})


##################
### Plots
##################

# Plot incidence
output$HARLOC_plot_incidence <- renderPlotly({
  
  # Variables
  HARLOCtype <- input$HARLOCtype
  HARLOCagg <- as.numeric(input$HARLOCagg)
  
  # Main plot configuration
  plot_incidence <- plot_ly() %>% 
    layout(xaxis = list(title = tr("date")), yaxis = list(title = tr("cases"))) %>%
    layout(legend = list(x = 0, y = -.25, orientation = 'h'), showlegend=TRUE)
  
  if(HARLOCtype == "center"){
    if(HARLOCagg == 1){
      # FG
      for(loc in unique(HARLOC_sub_fg()$id_center)){
        df <- HARLOC_sub_fg() %>% filter(id_center == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "day")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "day"), fill = list(counts = 0))
        loc_name <- HARLOC_health_center_fg[which(HARLOC_health_center_fg$id_center == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
      # BR
      for(loc in unique(HARLOC_sub_br()$id_center)){
        df <- HARLOC_sub_br() %>% filter(id_center == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "day")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "day"), fill = list(counts = 0))
        loc_name <- HARLOC_health_center_br[which(HARLOC_health_center_br$id_center == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
    } else if(HARLOCagg == 6){
      # FG
      for(loc in unique(HARLOC_sub_fg()$id_center)){
        df <- HARLOC_sub_fg() %>% filter(id_center == loc)
        tab <- as.data.frame(incidence(df$consultation_date, interval = 7, iso_week = TRUE))
        loc_name <- HARLOC_health_center_fg[which(HARLOC_health_center_fg$id_center == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
      # BR
      for(loc in unique(HARLOC_sub_br()$id_center)){
        df <- HARLOC_sub_br() %>% filter(id_center == loc)
        tab <- as.data.frame(incidence(df$consultation_date, interval = 7, iso_week = TRUE))
        loc_name <- HARLOC_health_center_br[which(HARLOC_health_center_br$id_center == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
    } else if(HARLOCagg == 30){
      # FG
      for(loc in unique(HARLOC_sub_fg()$id_center)){
        df <- HARLOC_sub_fg() %>% filter(id_center == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "month")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "month"), fill = list(counts = 0))
        loc_name <- HARLOC_health_center_fg[which(HARLOC_health_center_fg$id_center == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
      # BR
      for(loc in unique(HARLOC_sub_br()$id_center)){
        df <- HARLOC_sub_br() %>% filter(id_center == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "month")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "month"), fill = list(counts = 0))
        loc_name <- HARLOC_health_center_br[which(HARLOC_health_center_br$id_center == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
    } else if(HARLOCagg == 90){
      # FG
      for(loc in unique(HARLOC_sub_fg()$id_center)){
        df <- HARLOC_sub_fg() %>% filter(id_center == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "quarter")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "quarter"), fill = list(counts = 0))
        loc_name <- HARLOC_health_center_fg[which(HARLOC_health_center_fg$id_center == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
      # BR
      for(loc in unique(HARLOC_sub_br()$id_center)){
        df <- HARLOC_sub_br() %>% filter(id_center == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "quarter")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "quarter"), fill = list(counts = 0))
        loc_name <- HARLOC_health_center_br[which(HARLOC_health_center_br$id_center == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
    } else if(HARLOCagg == 366){
      # FG
      for(loc in unique(HARLOC_sub_fg()$id_center)){
        df <- HARLOC_sub_fg() %>% filter(id_center == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "year")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "year"), fill = list(counts = 0))
        loc_name <- HARLOC_health_center_fg[which(HARLOC_health_center_fg$id_center == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
      # BR
      for(loc in unique(HARLOC_sub_br()$id_center)){
        df <- HARLOC_sub_br() %>% filter(id_center == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "year")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "year"), fill = list(counts = 0))
        loc_name <- HARLOC_health_center_br[which(HARLOC_health_center_br$id_center == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
    }
  } else if(HARLOCtype == "residence_area"){
    if(HARLOCagg == 1){
      # FG
      for(loc in unique(HARLOC_sub_fg()$residence_place)){
        df <- HARLOC_sub_fg() %>% filter(residence_place == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "day")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "day"), fill = list(counts = 0))
        loc_name <- HARLOC_residencial_area_fg[which(HARLOC_residencial_area_fg$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
      # BR
      for(loc in unique(HARLOC_sub_br()$residence_place)){
        df <- HARLOC_sub_br() %>% filter(residence_place == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "day")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "day"), fill = list(counts = 0))
        loc_name <- HARLOC_residencial_area_br[which(HARLOC_residencial_area_br$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
    } else if(HARLOCagg == 6){
      # FG
      for(loc in unique(HARLOC_sub_fg()$residence_place)){
        df <- HARLOC_sub_fg() %>% filter(residence_place == loc)
        tab <- as.data.frame(incidence(df$consultation_date, interval = 7, iso_week = TRUE))
        loc_name <- HARLOC_residencial_area_fg[which(HARLOC_residencial_area_fg$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
      # BR
      for(loc in unique(HARLOC_sub_br()$residence_place)){
        df <- HARLOC_sub_br() %>% filter(residence_place == loc)
        tab <- as.data.frame(incidence(df$consultation_date, interval = 7, iso_week = TRUE))
        loc_name <- HARLOC_residencial_area_br[which(HARLOC_residencial_area_br$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
    } else if(HARLOCagg == 30){
      # FG
      for(loc in unique(HARLOC_sub_fg()$residence_place)){
        df <- HARLOC_sub_fg() %>% filter(residence_place == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "month")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "month"), fill = list(counts = 0))
        loc_name <- HARLOC_residencial_area_fg[which(HARLOC_residencial_area_fg$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
      # BR
      for(loc in unique(HARLOC_sub_br()$residence_place)){
        df <- HARLOC_sub_br() %>% filter(residence_place == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "month")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "month"), fill = list(counts = 0))
        loc_name <- HARLOC_residencial_area_br[which(HARLOC_residencial_area_br$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
    } else if(HARLOCagg == 90){
      # FG
      for(loc in unique(HARLOC_sub_fg()$residence_place)){
        df <- HARLOC_sub_fg() %>% filter(residence_place == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "quarter")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "quarter"), fill = list(counts = 0))
        loc_name <- HARLOC_residencial_area_fg[which(HARLOC_residencial_area_fg$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
      # BR
      for(loc in unique(HARLOC_sub_br()$residence_place)){
        df <- HARLOC_sub_br() %>% filter(residence_place == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "quarter")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "quarter"), fill = list(counts = 0))
        loc_name <- HARLOC_residencial_area_br[which(HARLOC_residencial_area_br$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
    } else if(HARLOCagg == 366){
      # FG
      for(loc in unique(HARLOC_sub_fg()$residence_place)){
        df <- HARLOC_sub_fg() %>% filter(residence_place == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "year")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "year"), fill = list(counts = 0))
        loc_name <- HARLOC_residencial_area_fg[which(HARLOC_residencial_area_fg$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
      # BR
      for(loc in unique(HARLOC_sub_br()$residence_place)){
        df <- HARLOC_sub_br() %>% filter(residence_place == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "year")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "year"), fill = list(counts = 0))
        loc_name <- HARLOC_residencial_area_br[which(HARLOC_residencial_area_br$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
    }
  } else if(input$HARLOCtype == "infection_place"){
    if(HARLOCagg == 1){
      # FG
      for(loc in unique(HARLOC_sub_fg()$infection_place)){
        df <- HARLOC_sub_fg() %>% filter(infection_place == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "day")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "day"), fill = list(counts = 0))
        loc_name <- HARLOC_residencial_area_fg[which(HARLOC_residencial_area_fg$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
      # BR
      for(loc in unique(HARLOC_sub_br()$infection_place)){
        df <- HARLOC_sub_br() %>% filter(infection_place == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "day")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "day"), fill = list(counts = 0))
        loc_name <- HARLOC_residencial_area_br[which(HARLOC_residencial_area_br$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
    } else if(HARLOCagg == 6){
      # FG
      for(loc in unique(HARLOC_sub_fg()$infection_place)){
        df <- HARLOC_sub_fg() %>% filter(infection_place == loc)
        tab <- as.data.frame(incidence(df$consultation_date, interval = 7, iso_week = TRUE))
        loc_name <- HARLOC_residencial_area_fg[which(HARLOC_residencial_area_fg$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
      # BR
      for(loc in unique(HARLOC_sub_br()$infection_place)){
        df <- HARLOC_sub_br() %>% filter(infection_place == loc)
        tab <- as.data.frame(incidence(df$consultation_date, interval = 7, iso_week = TRUE))
        loc_name <- HARLOC_residencial_area_br[which(HARLOC_residencial_area_br$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
    } else if(HARLOCagg == 30){
      # FG
      for(loc in unique(HARLOC_sub_fg()$infection_place)){
        df <- HARLOC_sub_fg() %>% filter(infection_place == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "month")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "month"), fill = list(counts = 0))
        loc_name <- HARLOC_residencial_area_fg[which(HARLOC_residencial_area_fg$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
      # BR
      for(loc in unique(HARLOC_sub_br()$infection_place)){
        df <- HARLOC_sub_br() %>% filter(infection_place == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "month")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "month"), fill = list(counts = 0))
        loc_name <- HARLOC_residencial_area_br[which(HARLOC_residencial_area_br$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
    } else if(HARLOCagg == 90){
      # FG
      for(loc in unique(HARLOC_sub_fg()$infection_place)){
        df <- HARLOC_sub_fg() %>% filter(infection_place == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "quarter")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "quarter"), fill = list(counts = 0))
        loc_name <- HARLOC_residencial_area_fg[which(HARLOC_residencial_area_fg$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
      # BR
      for(loc in unique(HARLOC_sub_br()$infection_place)){
        df <- HARLOC_sub_br() %>% filter(infection_place == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "quarter")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "quarter"), fill = list(counts = 0))
        loc_name <- HARLOC_residencial_area_br[which(HARLOC_residencial_area_br$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
    } else if(HARLOCagg == 366){
      # FG
      for(loc in unique(HARLOC_sub_fg()$infection_place)){
        df <- HARLOC_sub_fg() %>% filter(infection_place == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "year")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "year"), fill = list(counts = 0))
        loc_name <- HARLOC_residencial_area_fg[which(HARLOC_residencial_area_fg$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
      # BR
      for(loc in unique(HARLOC_sub_br()$infection_place)){
        df <- HARLOC_sub_br() %>% filter(infection_place == loc)
        tab <- df %>% 
          group_by(dates = floor_date(consultation_date, "year")) %>%
          summarize(counts=n()) %>%
          complete(dates = seq.Date(date1(), date2(), by = "year"), fill = list(counts = 0))
        loc_name <- HARLOC_residencial_area_br[which(HARLOC_residencial_area_br$id == loc), "name"]
        plot_incidence <- add_trace(plot_incidence, data = tab, x = ~dates, y = ~counts, type = 'scatter', mode = 'lines', name = loc_name)
      }
    }
  }
  
  # Plot
  plot_incidence
})



# Information completness
output$HARLOC_information_completness <- renderUI({
  tabBox(
    width = 12,
    height = "180px",
    title = tr("missing_information"),
    tabPanel(
      title = tr("infection_place"), 
      valueBox(paste0(round(HARLOC_sub_infqual_fg()["infection_place"],2),"%"), tr("FG"), color = "purple", width = 6),
      valueBox(paste0(round(HARLOC_sub_infqual_br()["infection_place"],2),"%"), tr("BR"), color = "purple", width = 6)
    ),
    tabPanel(
      title = tr("residence_area"), 
      valueBox(paste0(round(HARLOC_sub_infqual_fg()["residence_place"],2),"%"), tr("FG"), color = "purple", width = 6),
      valueBox(paste0(round(HARLOC_sub_infqual_br()["residence_place"],2),"%"), tr("BR"), color = "purple", width = 6)
    ),
    tabPanel(
      title = tr("center"), 
      valueBox(paste0(round(HARLOC_sub_infqual_fg()["id_center"],2),"%"), tr("FG"), color = "purple", width = 6),
      valueBox(paste0(round(HARLOC_sub_infqual_br()["id_center"],2),"%"), tr("BR"), color = "purple", width = 6)
    )
  )
})

# Day of the week plot
output$HARLOC_plot_day_week_br <- renderPlot({
  if(length(HARLOC_br_tab_day_week() > 0)){
    calendarHeat(dates = HARLOC_br_tab_day_week()$dates, values = HARLOC_br_tab_day_week()$counts, color="g2r")
  } else {
    plot.new()
  }
})
output$HARLOC_plot_day_week_fg <- renderPlot({
  if(length(HARLOC_fg_tab_day_week() > 0)){
    calendarHeat(dates = HARLOC_fg_tab_day_week()$dates, values = HARLOC_fg_tab_day_week()$counts, color="g2r")
  } else {
    plot.new()
  }
})

