# Dynamic server UI

# Menu itens
output$sidebarMenu <- renderMenu({
  sidebarMenu(id="tabs",
              menuItem(tr("tab_harmonizedIndicators"), tabName = "tab_harmonizedIndicators", icon = icon("bar-chart")),
              menuItem(tr("tab_harmonizedIndicators_loc"), tabName = "tab_harmonizedIndicators_loc", icon = icon("map-marker")),
              menuItem(tr("tab_ranking"), tabName = "tab_ranking", icon = icon("reorder")),
              menuItem(tr("tab_map"), tabName = "tab_map", icon = icon("map"))
              
              #menuItem(tr("tab_trends"), tabName = "tab_trends", icon = icon("line-chart")),
              #menuItem(tr("tab_infoq"), tabName = "tab_infoq", icon = icon("check-square-o")),
              #menuItem(tr("tab_download"), tabName = "tab_download", icon = icon("download"))
  )
})

# Select first tab
isolate({updateTabItems(session, "tabs", "tab_harmonizedIndicators")})

# Translated selection options 
ops_new_attack <- reactive({
  ops <- c(TRUE,FALSE,"Any")
  names(ops) <- c(tr("new_cases"),tr("old_cases"),tr("Any"))
  ops
})
ops_diagn <- reactive({
  ops <- c("Any","falciparum","mixed infection with P. falciparum","non-falciparum","unspecified")
  names(ops) <- c(tr("Any"),"Plasmodium falciparum",tr("mixed_falciparum"),tr("non_falciparum"),tr("Unspecified"))
  ops
})
ops_sex <- reactive({
  ops <- c("Any","Male","Female")
  names(ops) <-  c(tr("Any"),tr("male"),tr("female"))
  ops
})
ops_agg <- reactive({
  ops <- c(30,90,366)
  names(ops) <-  c(tr("30_days"),tr("90_days"),tr("yearly"))
  ops
})
ops_location <- reactive({
  ops <- c("center","residence_area","infection_place")
  names(ops) <-  c(tr("center"), tr("residence_area"), tr("infection_place"))
  ops
})
ops_location2 <- reactive({
  ops <- c("residence_area","infection_place")
  names(ops) <-  c(tr("residence_area"), tr("infection_place"))
  ops
})
ops_raster <- reactive({
  # noms des couches WMS
  ops <- c(
    "NO_SEL",
    "INTERACTION AVEC FORÊT/INTERAÇÃO COM  FLORESTA (NLHI)",
    "PROBABILITÉ PRÉSENCE VECTEUR/PROBABILIDADE PRESENÇA VETOR",
    "EMPREINTE HUMAINE/PEGADA HUMANA",
    "RISQUE D'EXPOSITION POP./RISCO DE EXPOSIÇÃO POP."
  )
  names(ops) <- c(
    "Pas de sélection",
    "Interaction avec forêt",
    "Probabilité Présence Vecteur",
    "Empreinte Humaine",
    "Risque d'exposition pop."
  )
  ops
})
ops_country <- reactive({
  ops <- c("Any","FG","BR")
  names(ops) <- c(tr("Any"),tr("FG"),tr("BR"))
  ops
})
ops_period <- reactive({
  ops <- c("last_week","last_month","last_three_months","last_semester","last_year","last_five_years")
  names(ops) <- c(tr("last_week"),tr("last_month"),tr("last_three_months"),tr("last_semester"),tr("last_year"),tr("last_five_years"))
  ops
})


# Tab Items
output$tabItems <- renderUI({
  tabItems(
    # Harmonized indicators
    tabItem(tabName = "tab_harmonizedIndicators",
            fluidRow(
              # Filter
              box(
                status = "warning", 
                solidHeader = TRUE,
                collapsible = TRUE,
                width = 12,
                title = tr("disclaimer_title"),
                tr("disclaimer_text")
              ),
              box(
                title = tr("filter"),
                width = 4,
                sliderInput('dates', tr("dateRange"), sep = "", step = 1, min = 2003, max = 2024, value = c(2007,2024)),
                selectInput('new_attack', tr("cases"), ops_new_attack(), selected = TRUE),
                selectInput('diagn', tr("plasmodium"), ops_diagn()),
                sliderInput('age', tr("age"), min = 0, max = 100, value = c(0,100)),
                selectInput('sex', tr("sex"), ops_sex()),
                selectInput('agg', tr("agg"), ops_agg(), selected = 30)
              ),
              # Counts
              valueBoxOutput("HAR_count_fg"),
              valueBoxOutput("HAR_count_br"),
              # Main plot
              box(
                title = tr("incidence"),
                width = 8,
                plotlyOutput("HAR_plot_incidence")
              ),
              # Age plots
              box(
                title = tr("age"),
                width = 12,
                plotlyOutput("HAR_plot_age")
              ),
              # Bar plots
              box(
                title = tr("sex"),
                width = 6,
                plotlyOutput("HAR_plot_sex")
              ),
              box(
                title = tr("plasmodium"),
                width = 6,
                plotlyOutput("HAR_plot_plasm")
              )
            )
            
    ),
    # Harmonized indicators location
    tabItem(tabName = "tab_harmonizedIndicators_loc",
            fluidRow(
              # Filter
              box(
                title = tr("filter"),
                width = 4,
                selectInput('HARLOCtype', tr("type"), ops_location()),
                uiOutput('HARLOClocation_fg'),
                uiOutput('HARLOClocation_br'),
                sliderInput('HARLOCdates', tr("dateRange"), sep = "", step = 1, min = 2003, max = 2024, value = c(2010,2024)),
                selectInput('HARLOCnew_attack', tr("new_attack"), ops_new_attack(), selected = TRUE),
                selectInput('HARLOCdiagn', tr("plasmodium"), ops_diagn()),
                sliderInput('HARLOCage', tr("age"), min = 0, max = 100, value = c(0,100)),
                selectInput('HARLOCsex', tr("sex"), ops_sex()),
                selectInput('HARLOCagg', tr("agg"), ops_agg(), selected = 30)
              ),
              box(
                title = tr("incidence"),
                width = 8,
                plotlyOutput("HARLOC_plot_incidence")
              ),
              box(
                width = 8,
                uiOutput("HARLOC_information_completness")
              )
            ),
            fluidRow(
              # Day of the week plot
              box(
                title = tr("FG"),
                width = 6,
                plotOutput("HARLOC_plot_day_week_fg", height = "600px")
              ),
              box(
                title = tr("BR"),
                width = 6,
                plotOutput("HARLOC_plot_day_week_br", height = "600px")
              )
            )
            
    ),
    # Maps
    tabItem(tabName = "tab_map",
            fluidRow(
              tags$head(
                tags$link(rel = "stylesheet", type = "text/css", href = "styles.css")
              ),
              leafletOutput("map"),
              absolutePanel(id = "controls",
                            class = "panel panel-default",
                            fixed = TRUE,
                            width = 330, height = "auto",
                            top = 100, left = "auto", right = 10, bottom = "auto",
                            draggable = TRUE,
                            selectInput('MAPtype', tr("type"), ops_location2(), selected = "residence_area"),
                            sliderInput('MAPdates', tr("dateRange"), sep = "", step = 1, min = 2003, max = 2024, value = c(2007,2024), animate = TRUE),
                            selectInput('MAPdiagn', tr("plasmodium"), ops_diagn()),
                            checkboxGroupInput('MAPosm', "OSM layers", c("Hospitals", "Clinics"), inline=TRUE),
                            # checkboxGroupInput('MAPgbif', "GBIF layers", c("Anopheles darlingi", "Anopheles marajoara"), inline=TRUE),
                            checkboxGroupInput('MAPgbif', "GBIF layers", c("Anopheles darlingi"), inline=TRUE),
                            selectInput('MAPrasters', "Raster models", ops_raster(), selected = "NO_SEL"),
                            uiOutput('MAPlegend'),
                            textOutput('MAPmissing')
              )
            )
    ),
    # Ranking
    tabItem(tabName = "tab_ranking",
            fluidRow(
              # Filter
              box(
                title = tr("filter"),
                width = 4,
                selectInput('RANKtype', tr("type"), ops_location()),
                sliderInput('RANKdates', tr("dateRange"), sep = "", step = 1, min = 2003, max = 2024, value = c(2010,2024)),
                selectInput('RANKnew_attack', tr("new_attack"), ops_new_attack(), selected = TRUE),
                selectInput('RANKdiagn', tr("plasmodium"), ops_diagn()),
                sliderInput('RANKage', tr("age"), min = 0, max = 100, value = c(0,100)),
                selectInput('RANKsex', tr("sex"), ops_sex())
              ),
              box(
                width = 8,
                dataTableOutput('RANK_table')
              )
            )
    ),
    # Download
    tabItem(tabName = "tab_download",
            fluidRow(
              # Filter
              box(
                title = tr("filter"),
                width = 4,
                selectInput('DOWNtype', tr("type"), ops_location()),
                sliderInput('DOWNdates', tr("dateRange"), sep = "", step = 1, min = 2003, max = 2024, value = c(2010,2024)),
                selectInput('DOWNnew_attack', tr("new_attack"), ops_new_attack(), selected = TRUE),
                selectInput('DOWNdiagn', tr("plasmodium"), ops_diagn()),
                sliderInput('DOWNage', tr("age"), min = 0, max = 100, value = c(0,100)),
                selectInput('DOWNsex', tr("sex"), ops_sex())
              ),
              box(
                title = tr("FG"),
                width = 4,
                uiOutput('DOWNlocation_fg')
              ),
              box(
                title = tr("BR"),
                width = 4,
                uiOutput('DOWNlocation_br')
              )
            ),
            fluidRow(
              box(
                width = 12,
                dataTableOutput('DOWN_table')
              )
            )
    ),
    # Trends
    # tabItem(tabName = "tab_trends",
    #         fluidRow(
    #           # Filter
    #           box(
    #             title = tr("filter"),
    #             width = 4,
    #             selectInput('TRENDStype', tr("type"), ops_location(), selected = "residence_area"),
    #             selectInput('TRENDSnew_attack', tr("new_attack"), ops_new_attack(), selected = TRUE),
    #             selectInput('TRENDSdiagn', tr("plasmodium"), ops_diagn()),
    #             sliderInput('TRENDSage', tr("age"), min = 0, max = 100, value = c(0,100)),
    #             selectInput('TRENDSsex', tr("sex"), ops_sex())
    #           ),
    #           box(
    #             width = 8,
    #             dataTableOutput('TRENDS_table')
    #           )
    #         )
    # ),
    # Information quality
    tabItem(tabName = "tab_infoq",
            fluidRow(
              # Filter
              box(
                title = tr("filter"),
                width = 4,
                selectInput("INFOQcountry", tr("country"), ops_country()),
                selectInput('INFOQtype', tr("type"), ops_location()),
                uiOutput('INFOQlocation_fg'),
                uiOutput('INFOQlocation_br'),
                sliderInput('INFOQdates', tr("dateRange"), sep = "", step = 1, min = 2003, max = 2024, value = c(2010,2024)),
                selectInput('INFOQnew_attack', tr("new_attack"), ops_new_attack(), selected = "Any"),
                selectInput('INFOQdiagn', tr("plasmodium"), ops_diagn(), selected = "Any"),
                selectInput('INFOQsex', tr("sex"), ops_sex())
              ),
              box(
                title = "Misssing information",
                width = 8,
                tabBox(
                  width = 12,
                  tabPanel(
                    title = tr("sex"),
                    plotlyOutput("INFOQ_plot_sex")
                  ),
                  tabPanel(
                    title = tr("residence_area"),
                    plotlyOutput("INFOQ_plot_residence_area")
                  ),
                  tabPanel(
                    title = tr("infection_place"),
                    plotlyOutput("INFOQ_plot_infection_place")
                  ),
                  tabPanel(
                    title = tr("center"),
                    plotlyOutput("INFOQ_plot_center")
                  )
                )
              )
            ),
            fluidRow(
              box(
                width = 12,
                dataTableOutput('INFOQ_ftable')
              )
            )
    )
  )
})



# Handle translation change
observeEvent(input$language, {
  currentTab <- input$tabs # Get current tab
  updateTabItems(session, "tabs", currentTab) # Set current tab after getting translation
})
